@@ -1,22 +1,29 @@
+//! # `/derivatives`
+//!
+//! - [/derivatives](Derivatives)
+//! - [/derivatives/exchanges](Exchanges)
+//! - [/derivatives/exchanges/{id}](Info)
+//! - [/derivatives/exchanges/list](List)
+//!
 use crate::Route;
 
 pub struct Derivatives {
-    endpoint: String,            // /derivatives
+    endpoint: String,
     pub include_tickers: String, // 'all' or 'expired'
 }
 pub struct Exchanges {
-    endpoint: String,  // /derivatives/exchanges
+    endpoint: String,
     pub order: String, // name_asc，name_desc，open_interest_btc_asc，open_interest_btc_desc，trade_volume_24h_btc_asc，trade_volume_24h_btc_desc
     pub per_page: i32,
     pub page: i32,
 }
 pub struct Info {
-    endpoint: String, // /derivatives/exchanges/{id}
+    endpoint: String,
     pub id: String,
     pub include_tickers: String, // 'all' or 'expired'
 }
 pub struct List {
-    endpoint: String, // /derivatives/exchanges/list
+    endpoint: String,
 }
 
 impl Derivatives {
