@@ -1,7 +1,13 @@
+//! # `/events`
+//!
+//! - [/events](Events)
+//! - [/events/countries](Countries)
+//! - [/events/types](Types)
+//!
 use crate::Route;
 
 pub struct Events {
-    endpoint: String, // /events
+    endpoint: String,
     pub country_code: String,
     pub ev_type: String,
     pub page: i32,
@@ -10,10 +16,10 @@ pub struct Events {
     pub to_date: String,
 }
 pub struct Countries {
-    endpoint: String, // /events/countries
+    endpoint: String,
 }
 pub struct Types {
-    endpoint: String, // /events/types
+    endpoint: String,
 }
 
 impl Events {
