@@ -1,7 +1,10 @@
+//! # `/exchange_rates`
+//!
+//! - [/exchange_rates](ExchangeRates)
 use crate::Route;
 
 pub struct ExchangeRates {
-    endpoint: String, // /exchange_rates
+    endpoint: String,
 }
 
 impl ExchangeRates {
