@@ -1,19 +1,27 @@
+//! # `/exchange`
+//!
+//! - [/exchanges](Exchanges)
+//! - [/exchanges/list](List)
+//! - [/exchanges/{id}](Info)
+//! - [/exchanges/{id}/tickers](Tickers)
+//! - [/exchanges/{id}/status_updates](StatusUpdates)
+//! - [/exchanges/{id}/volume_chart](VolumeChart)
 use crate::Route;
 
 pub struct Exchanges {
-    endpoint: String, // /exchanges
+    endpoint: String,
     pub per_page: i32,
     pub page: i32,
 }
 pub struct List {
-    endpoint: String, // /exchanges/list
+    endpoint: String,
 }
 pub struct Info {
-    endpoint: String, // /exchanges/{id}
+    endpoint: String,
     pub id: String,
 }
 pub struct Tickers {
-    endpoint: String, // /exchanges/{id}/tickers
+    endpoint: String,
     pub id: String,
     pub coin_ids: String,
     pub include_exchange_logo: bool,
@@ -22,12 +30,12 @@ pub struct Tickers {
     pub order: String,
 }
 pub struct StatusUpdates {
-    endpoint: String, // /exchanges/{id}/status_updates
+    endpoint: String,
     pub id: String,
     pub per_page: i32,
     pub page: i32,
 }
-pub struct VolumeData {
+pub struct VolumeChart {
     endpoint: String,
     pub id: String,
     pub days: String,
@@ -67,9 +75,9 @@ impl StatusUpdates {
         }
     }
 }
-impl VolumeData {
-    pub fn required(id: String, days: String) -> VolumeData {
-        VolumeData {
+impl VolumeChart {
+    pub fn required(id: String, days: String) -> VolumeChart {
+        VolumeChart {
             id,
             days,
             ..Default::default()
@@ -124,9 +132,9 @@ impl Default for StatusUpdates {
         }
     }
 }
-impl Default for VolumeData {
-    fn default() -> VolumeData {
-        VolumeData {
+impl Default for VolumeChart {
+    fn default() -> VolumeChart {
+        VolumeChart {
             endpoint: String::from("/exchanges/ID/volume_chart"),
             id: String::from(""),
             days: String::from(""),
@@ -201,13 +209,13 @@ impl Route for StatusUpdates {
         self.collect_query_params(optional)
     }
 }
-impl Route for VolumeData {
+impl Route for VolumeChart {
     fn api_endpoint(&self) -> String {
         let endpoint = self.endpoint.replace("ID", &(self.id));
         format!("{}", endpoint)
     }
     fn query_string(&self) -> String {
-        let default: VolumeData = Default::default();
+        let default: VolumeChart = Default::default();
         let days = self.format_query("days".to_string(), &(self.days), &(default.days));
         let optional = vec![days];
         self.collect_query_params(optional)
