@@ -1,12 +1,16 @@
+//! # `/finance`
+//!
+//! - [/finance_platforms](Platforms)
+//! - [/finance_products](Products)
 use crate::Route;
 
 pub struct Platforms {
-    endpoint: String, // /finance_platforms
+    endpoint: String,
     pub per_page: i32,
     pub page: i32,
 }
 pub struct Products {
-    endpoint: String, // /finance_products
+    endpoint: String,
     pub per_page: i32,
     pub page: i32,
     pub start_at: String, // date
